
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "gcr-enum-types.h"
#include "gcr-ui.h"
#include "gcr-certificate-renderer.h"
#include "gcr-certificate-widget.h"
#include "gcr-collection-model.h"
#include "gcr-combo-selector.h"
#include "gcr-deprecated.h"
#include "gcr-failure-renderer.h"
#include "gcr-key-renderer.h"
#include "gcr-key-widget.h"
#include "gcr-import-button.h"
#include "gcr-list-selector.h"
#include "gcr-prompt-dialog.h"
#include "gcr-renderer.h"
#include "gcr-secure-entry-buffer.h"
#include "gcr-tree-selector.h"
#include "gcr-unlock-options-widget.h"
#include "gcr-viewer.h"
#include "gcr-viewer-widget.h"

#define C_ENUM(v) ((gint) v)
#define C_FLAGS(v) ((guint) v)

/* enumerations from "gcr-collection-model.h" */

GType
gcr_collection_model_mode_get_type (void)
{
static gsize gtype_id = 0;
static const GEnumValue values[] = {
    { C_ENUM(GCR_COLLECTION_MODEL_LIST), "GCR_COLLECTION_MODEL_LIST", "list" },
    { C_ENUM(GCR_COLLECTION_MODEL_TREE), "GCR_COLLECTION_MODEL_TREE", "tree" },
{ 0, NULL, NULL }
        };
        if (g_once_init_enter (&gtype_id)) {
            GType new_type = g_enum_register_static (g_intern_static_string ("GcrCollectionModelMode"), values);
            g_once_init_leave (&gtype_id, new_type);
        }
        return (GType) gtype_id;
        }

/* Generated data ends here */

